Action class

Specifies an action for an event-based policy.

Constructors

Action({required List<CrossRegionCopyAction> crossRegionCopy, required String name})
Action.fromJson(Map<String, dynamic> json)
factory

Properties

crossRegionCopy → List<CrossRegionCopyAction>
The rule for copying shared snapshots across Regions.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
A descriptive name for the action.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited