CreateRule class

Specifies when to create snapshots of EBS volumes.

You must specify either a Cron expression or an interval, interval unit, and start time. You cannot specify both.

Constructors

CreateRule({String? cronExpression, int? interval, IntervalUnitValues? intervalUnit, List<String>? times})
CreateRule.fromJson(Map<String, dynamic> json)
factory

Properties

cronExpression → String?
The schedule, as a Cron expression. The schedule interval must be between 1 hour and 1 year. For more information, see Cron expressions in the Amazon CloudWatch User Guide.
final
hashCode → int
The hash code for this object.
no setterinherited
interval → int?
The interval between snapshots. The supported values are 1, 2, 3, 4, 6, 8, 12, and 24.
final
intervalUnit → IntervalUnitValues?
The interval unit.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
times → List<String>?
The time, in UTC, to start the operation. The supported format is hh:mm.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited