CrossRegionCopyRetainRule class

Specifies the retention rule for cross-Region snapshot copies.

Constructors

CrossRegionCopyRetainRule({int? interval, RetentionIntervalUnitValues? intervalUnit})
CrossRegionCopyRetainRule.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
interval → int?
The amount of time to retain each snapshot. The maximum is 100 years. This is equivalent to 1200 months, 5200 weeks, or 36500 days.
final
intervalUnit → RetentionIntervalUnitValues?
The unit of time for time-based retention.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited