EventParameters class

Specifies an event that triggers an event-based policy.

Constructors

EventParameters({required String descriptionRegex, required EventTypeValues eventType, required List<String> snapshotOwner})
EventParameters.fromJson(Map<String, dynamic> json)
factory

Properties

descriptionRegex → String
The snapshot description that can trigger the policy. The description pattern is specified using a regular expression. The policy runs only if a snapshot with a description that matches the specified pattern is shared with your account.
final
eventType → EventTypeValues
The type of event. Currently, only snapshot sharing events are supported.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snapshotOwner → List<String>
The IDs of the AWS accounts that can trigger policy by sharing snapshots with your account. The policy only runs if one of the specified AWS accounts shares a snapshot with your account.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited