FastRestoreRule class

Specifies a rule for enabling fast snapshot restore. You can enable fast snapshot restore based on either a count or a time interval.

Constructors

FastRestoreRule({required List<String> availabilityZones, int? count, int? interval, RetentionIntervalUnitValues? intervalUnit})
FastRestoreRule.fromJson(Map<String, dynamic> json)
factory

Properties

availabilityZones → List<String>
The Availability Zones in which to enable fast snapshot restore.
final
count → int?
The number of snapshots to be enabled with fast snapshot restore.
final
hashCode → int
The hash code for this object.
no setterinherited
interval → int?
The amount of time to enable fast snapshot restore. The maximum is 100 years. This is equivalent to 1200 months, 5200 weeks, or 36500 days.
final
intervalUnit → RetentionIntervalUnitValues?
The unit of time for enabling fast snapshot restore.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited