RetainRule class

Specifies the retention rule for a lifecycle policy. You can retain snapshots based on either a count or a time interval.

Constructors

RetainRule({int? count, int? interval, RetentionIntervalUnitValues? intervalUnit})
RetainRule.fromJson(Map<String, dynamic> json)
factory

Properties

count → int?
The number of snapshots to retain for each volume, up to a maximum of 1000.
final
hashCode → int
The hash code for this object.
no setterinherited
interval → int?
The amount of time to retain each snapshot. The maximum is 100 years. This is equivalent to 1200 months, 5200 weeks, or 36500 days.
final
intervalUnit → RetentionIntervalUnitValues?
The unit of time for time-based retention.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited